@@ -2,6 +2,7 @@ import discover
 import optimset
 
 import netCDF4
+import h5py
 
 import nc_Database
 import netcdf_soft_links
@@ -83,21 +84,18 @@ class SimpleTree:
             print "cdb_query will now attempt to confirm that these simulations have all the requested variables."
             print "This can take some time. Please abort if there are not enough simulations for your needs."
 
-            if options.num_procs==1:
-                filepath=discover.discover(self,options)
-                try:
-                    os.rename(filepath,filepath.replace('.pid'+str(os.getpid()),''))
-                except OSError:
-                    pass
-            else:
-                #Find the atomic simulations:
-                simulations_list=discover.discover_simulations_recursive(self,options,self.drs.simulations_desc)
+            #if options.num_procs==1:
+            #    filepath=discover.discover(self,options)
+            #    try:
+            #        os.rename(filepath,filepath.replace('.pid'+str(os.getpid()),''))
+            #    except OSError:
+            #        pass
+            #else:
+            manager=multiprocessing.Manager()
+            output=distributed_recovery(discover.discover,self,options,simulations_list,manager)
 
-                manager=multiprocessing.Manager()
-                output=distributed_recovery(discover.discover,self,options,simulations_list,manager)
-
-                #Close dataset
-                output.close()
+            #Close dataset
+            output.close()
         return
 
     def validate(self,options):
@@ -124,9 +122,11 @@ class SimpleTree:
             #Find the atomic simulations:
             if simulations_list==[]:
                 simulations_list=self.list_fields_local(options,self.drs.simulations_desc)
-            for simulation in simulations_list:
-                if simulation[-1]!='r0i0p0':
-                    print '_'.join(simulation)
+
+            #for simulation in simulations_list:
+            #    #if simulation[-1]!='r0i0p0':
+            #    print '_'.join(simulation)
+            #print "Validating"
 
             #Randomize the list:
             import random
@@ -265,14 +265,16 @@ class SimpleTree:
         self.close_database()
         return
 
-    def load_database(self,options,find_function):
+    def load_database(self,options,find_function,semaphores=None):
         self.define_database(options)
-        self.nc_Database.populate_database(options,find_function)
+        if 'header' in dir(self):
+            self.nc_Database.header=self.header
+        self.nc_Database.populate_database(options,find_function,semaphores=semaphores)
         if 'ensemble' in dir(options) and options.ensemble!=None:
             #Always include r0i0p0 when ensemble was sliced:
             options_copy=copy.copy(options)
             options_copy.ensemble='r0i0p0'
-            self.nc_Database.populate_database(options_copy,find_function)
+            self.nc_Database.populate_database(options_copy,find_function,semaphores=semaphores)
         return
 
     def close_database(self):
@@ -314,7 +316,14 @@ def distributed_recovery(function_handle,database,options,simulations_list,manag
             result=worker_query(arg)
         filename=queue_result.get()
         source_data=netCDF4.Dataset(filename,'r')
-        nc_Database.record_to_file(output_root,source_data)
+        source_data_hdf5=h5py.File(filename,'r')
+        nc_Database.record_to_file(output_root,source_data,source_data_hdf5)
+        source_data_hdf5.close()
+        source_data.close()
+        try:
+            os.remove(filename)
+        except OSError:
+            pass
         output_root.sync()
     if options.num_procs>1:
         pool.close()
@@ -407,7 +416,7 @@ def progress_report(retrieval_function,output,tuple,queues,queues_size,data_node
         #    print data_node, queues[data_node].qsize()
     return
         
-def find_simple(pointers,file_expt):
+def find_simple(pointers,file_expt,semaphores=None):
     #for item in dir(file_expt):
     #    if item[0]!='_':
     #        print getattr(file_expt,item)
