@@ -73,6 +73,17 @@ class nc_Database:
         self.file_expt.time='0'
         populate_database_recursive(self,self.Dataset,options,find_function,semaphores=semaphores)
         self.close_nc_file()
+
+        #Allow complex queries:
+        if ('field' in dir(options) and options.field!=[] and options.field!=None):
+            if ( 'complex_query' in dir(options) and options.complex_query!=[] or
+                 'Xcomplex_query' in dir(options) and options.Xcomplex_query!=[]  ):
+                list_query=self.list_fields(options.field)
+                for query in list_query:
+                    if ( (options.complex_query!=[] and not query in options.complex_query) or
+                         (options.Xcomplex_query!=[] and query in options.Xcomplex_query) ):
+                        conditions=[ getattr(File_Expt,field)==query[field_id] for field_id, field in enumerate(options.field)]
+                        self.session.query(File_Expt).filter(*conditions).delete()
         return
 
     def simulations_list(self):
@@ -336,10 +347,10 @@ def is_level_name_included_and_not_excluded(level_name,options,group):
         not_excluded=True
     return included and not_excluded
 
-def record_to_file(output_root,output):
+def record_to_file(output_root,output,output_hdf5):
     netcdf_utils.replicate_netcdf_file(output_root,output)
     #netcdf_utils.replicate_full_netcdf_recursive(output_root,output,check_empty=True)
-    netcdf_utils.replicate_full_netcdf_recursive(output_root,output,check_empty=False)
+    netcdf_utils.replicate_full_netcdf_recursive(output_root,output,check_empty=False,hdf5=output_hdf5)
     return
 
 class File_Expt(object):
