@@ -4,6 +4,23 @@ import retrieval_utils
 import netcdf_utils
 import time
 import sys
+import os
+
+class RedirectStdStreams(object):
+    def __init__(self, stdout=None, stderr=None):
+        self._stdout = stdout or sys.stdout
+        self._stderr = stderr or sys.stderr
+
+    def __enter__(self):
+        self.old_stdout, self.old_stderr = sys.stdout, sys.stderr
+        self.old_stdout.flush(); self.old_stderr.flush()
+        sys.stdout, sys.stderr = self._stdout, self._stderr
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        self._stdout.flush(); self._stderr.flush()
+        sys.stdout = self.old_stdout
+        sys.stderr = self.old_stderr
+
 
 class remote_netCDF:
     def __init__(self,netcdf_file_name,semaphores):
@@ -68,6 +85,8 @@ not available or out of date.'''.splitlines()).format(self.file_name.replace('do
 
     def is_available(self):
         try:
+            #devnull = open(os.devnull, 'w')
+            #with RedirectStdStreams(stdout=devnull, stderr=devnull):
             self.open_with_error()
             self.close()
             return True
